@@ -48,6 +48,8 @@ class EmacsLispDomain(Domain):
                            searchprio=1),
         'variable': ObjType('variable', 'variable', scope='variable',
                             searchprio=0),
+        'constant': ObjType('constant', 'constant', scope='variable',
+                            searchprio=0),
         'option': ObjType('user option', 'option', scope='variable',
                           searchprio=1),
         'hook': ObjType('hook', 'hook', scope='variable',
@@ -62,6 +64,7 @@ class EmacsLispDomain(Domain):
         'macro': desc.EmacsLispFunction,
         'command': desc.EmacsLispCommand,
         'variable': desc.EmacsLispVariable,
+        'constant': desc.EmacsLispVariable,
         'option': desc.EmacsLispVariable,
         'hook': desc.EmacsLispVariable,
         'face': desc.EmacsLispFace,
@@ -75,6 +78,7 @@ class EmacsLispDomain(Domain):
         'macro': XRefRole(),
         'command': XRefRole(),
         'variable': XRefRole(),
+        'constant': XRefRole(),
         'option': XRefRole(),
         'hook': XRefRole(),
         'face': XRefRole(),
